#!/usr/bin/env python3

from comflow.tabulardata import *
import numpy as np
import matplotlib.pyplot as plt
import os



#########################################################
# Option 1:
# quick plot using the ComFLOW library, 
# input argument is a list of 3-tuples [(X expression, Y expression, Legend entry),...]
### ax,lines = td.plot([ ("Time","Pressure", "Monitor point P11") ])
simulations = [
["h200cm/proc_1", "CFD, h=200cm"],
]

#########################################################
# Option 2: 
# use the [] operator to evaluate (complex) expressions as Numpy arrays 
# and use custom plotting

td_exp = TabularData(r"./202003_P11_COL.dat", type=NUMBERED_COLUMNS)
toffset_exp = 1118.
poffset_exp = -22.
t_exp = td_exp["Column0"] - toffset_exp
p_exp = td_exp["Column1"] - poffset_exp


fig = plt.figure()
fig.patch.set_facecolor('#ffffff')
ax = fig.gca()

ax.plot(t_exp, p_exp, label="P11 (Experiment)")

for s in simulations:

    # Load the time trace data
    td = TabularData(os.path.join(s[0],"mntrp0011.bin"))

    # Print available columns in time trace file
    # print(td.columns.keys())

    t_cfd = td["Time"]
    p_cfd = td["Pressure/1000."]            # pressure in kPa
    p_cfd[np.isnan(p_cfd)] = 0.             # pressure in vacuum is stored as NaN, set to 0
    mask_cfd = t_cfd>0.1                    # skip first part of signal to exclude startup effects

    ax.plot(t_cfd[mask_cfd], p_cfd[mask_cfd], label="P11 ({})".format(s[1]))



# Additional plot properties
ax.legend()
plt.xlim(0.,30.)

plt.savefig('plot_p11.png', bbox_inches='tight')

# Display on screen
plt.show()
