#!/usr/bin/env python3

from comflow.tabulardata import *
import numpy as np
import matplotlib.pyplot as plt
import os



#########################################################
# Option 1:
# quick plot using the ComFLOW library, 
# input argument is a list of 3-tuples [(X expression, Y expression, Legend entry),...]
### ax,lines = td.plot([ ("Time","Pressure", "Monitor point P11") ])
simulations = [
["h200cm/proc_1", "CFD, h=200cm"],
]

#########################################################
# Option 2: 
# use the [] operator to evaluate (complex) expressions as Numpy arrays 
# and use custom plotting

td_exp = TabularData(r"./202003_REL_5.dat", type=NUMBERED_COLUMNS)
toffset_cfd = 1118.
t_exp = td_exp["Column0"] - toffset_cfd
wh_exp = td_exp["Column1"]


fig = plt.figure()
fig.patch.set_facecolor('#ffffff')
ax = fig.gca()

ax.plot(t_exp, wh_exp, label="RELWH5 (Experiment)")

for s in simulations:

    # Load the time trace data
    td = TabularData(os.path.join(s[0],"fill0005.bin"))

    # Print available columns in time trace file
    # print(td.columns.keys())

    t_cfd = td["Time"]
    wh_cfd = td["-6. + 0.01*Percentage * 18."]    # water height w.r.t. z=0
    mask_cfd = t_cfd>0.1                          # skip first part of signal to exclude startup effects

    ax.plot(t_cfd[mask_cfd], wh_cfd[mask_cfd], label="RELWH5 ({})".format(s[1]))



# Additional plot properties
ax.legend()
plt.xlim(0.,30.)

plt.savefig('plot_relwh5.png', bbox_inches='tight')

# Display on screen
plt.show()
